# cookiecutter-pypackage-example

[![Release](https://img.shields.io/github/v/release/xdurana/cookiecutter-pypackage-example)](https://img.shields.io/github/v/release/xdurana/cookiecutter-pypackage-example)
[![Build status](https://img.shields.io/github/workflow/status/xdurana/cookiecutter-pypackage-example/merge-to-main)](https://img.shields.io/github/workflow/status/xdurana/cookiecutter-pypackage-example/merge-to-main)
[![Commit activity](https://img.shields.io/github/commit-activity/m/xdurana/cookiecutter-pypackage-example)](https://img.shields.io/github/commit-activity/m/xdurana/cookiecutter-pypackage-example)
[![Docs](https://img.shields.io/badge/docs-gh--pages-blue)](https://xdurana.github.io/cookiecutter-pypackage-example/)
[![Code style with black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports with isort](https://img.shields.io/badge/%20imports-isort-%231674b1)](https://pycqa.github.io/isort/)
[![License](https://img.shields.io/github/license/xdurana/cookiecutter-pypackage-example)](https://img.shields.io/github/license/xdurana/cookiecutter-pypackage-example)

This is a template repository for Python projects that use Poetry for their dependency management.

- **Github repository**: <https://github.com/xdurana/cookiecutter-pypackage-example/>
- **Documentation** <https://xdurana.github.io/cookiecutter-pypackage-example/>

## Releasing a new version

- Create an API Token on [Pypi](https://pypi.org/).
- Add the API Token to your projects secrets with the name `PYPI_TOKEN` by visiting
[this page](https://github.com/xdurana/cookiecutter-pypackage-example/settings/secrets/actions/new).
- Create a [new release](https://github.com/xdurana/cookiecutter-pypackage-example/releases/new) on Github.
Create a new tag in the form ``*.*.*``.

For more details, see [here](https://xdurana.github.io/cookiecutter-pypackage/releasing.html).

---

Repository initiated with [xdurana/cookiecutter-pypackage](https://github.com/xdurana/cookiecutter-pypackage).
